# How to contribute to JPMC projects

We welcome your patches and enhancements to our projects. We have a few basic conditions for contributing below.

## Contributor Agreements

We requrie all contributors to JPMC projects to complete our Contribution Licence Agreement (CLA). You can sign as an individual or as representing your company. You only need to do this once and it covers all current and future projects managed under our GitHub organization. 

The contribution agreement can be found here [JPMC CLA](https://github.com/jpmorganchase/.github/blob/main/Contribution%20License%20Agreement%20(CLA)%20JPMC%202022.pdf), follow the instructions to complete and return to [opensource_cla@jpmorgan.com](mailto:opensource_cla@jpmorgan.com)

## Code Reviews

All submission to projects from any source require code review by project maintainers. We are using GitHub pull requests to enforce code reviews. For more information on GitHub pull requests see [GitHub docs](https://docs.github.com/)

Open Source @ JPMorgan Chase 2022
